import type { ResourceRepositoryTreeDto } from '@/api/resource/model/repositoryModel'
import { apiGetRepositoryList } from '@/api/resource/repository'
import { onMounted, reactive, ref, unref } from 'vue'
import mitter from '@/utils/eventBus'

export function useRepositoryTree() {
  const fieldNames = reactive({
    children: 'childNode',
    title: 'resourceTableTitle',
    key: 'resourceTypeId'
  })
  const selectedNodeData = reactive<Recordable>({})
  const openNode = reactive<Recordable>({})
  const selectedKeys = ref<(string | number)[]>([])
  const treeList = ref<ResourceRepositoryTreeDto[]>([])
  const open = ref(false)

  const getTreeList = async () => {
    const { result } = await apiGetRepositoryList()
    treeList.value = result
    // 设置默认选中第一个
    onSelect([result[0].resourceTypeId])
  }

  const onSelect = (keys: (string | number)[], e?: any) => {
    e && Object.assign(selectedNodeData, e.node.data)
    selectedKeys.value = keys
    // 触发 表格 查询
    mitter.emit('treeSelect', unref(selectedKeys))
  }

  const onContextMenuClick = (key: any, node: any) => {
    Object.assign(openNode, node)
    open.value = true
  }

  onMounted(async () => {
    await getTreeList()
  })

  return {
    open,
    openNode,
    fieldNames,
    treeList,
    selectedKeys,
    onSelect,
    onContextMenuClick
  }
}
