import { onBeforeUnmount, ref } from 'vue'
import mitter from '@/utils/eventBus'
import { apiGetResourceField, apiGetResourceFieldValue } from '@/api/resource/repository'
import type { ResourceFieldDto } from '@/api/resource/model/repositoryModel'

export function useResourceFieldsTable() {
  const tableData = ref<Recordable[]>([])
  const tableColumns = ref<ResourceFieldDto[]>([])
  const loading = ref(false)

  mitter.on('treeSelect', async ([key]: any) => {
    if (key) {
      loading.value = true
      try {
        await getColumn(key)
        await getTableData(key)
      } catch {}
      loading.value = false
    }
  })

  /**
   * 获取表格动态列
   * @param key
   */
  const getColumn = async (key: any) => {
    const { result } = await apiGetResourceField(key)
    tableColumns.value = result
  }

  /**
   * 获取表格数据
   */
  const getTableData = async (key: any) => {
    const {result } =await apiGetResourceFieldValue(key)
    tableData.value = result
  }

  onBeforeUnmount(() => {
    mitter.off('treeSelect')
  })

  return {
    loading,
    tableData,
    tableColumns
  }
}
